[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
master 9364c28959a: ; Fix typos in symbol names
From: |
Stefan Kangas |
Subject: |
master 9364c28959a: ; Fix typos in symbol names |
Date: |
Sun, 21 Jan 2024 09:29:03 -0500 (EST) |
branch: master
commit 9364c28959a5b00e8ffd5d0d283ff0c0042f1bb0
Author: Stefan Kangas <stefankangas@gmail.com>
Commit: Stefan Kangas <stefankangas@gmail.com>
; Fix typos in symbol names
---
admin/cus-test.el | 2 +-
lisp/emacs-lisp/comp-cstr.el | 2 +-
lisp/erc/erc-button.el | 2 +-
lisp/erc/erc-track.el | 2 +-
lisp/filesets.el | 2 +-
lisp/forms.el | 2 +-
lisp/jsonrpc.el | 2 +-
lisp/net/tramp-sh.el | 2 +-
lisp/org/ox-latex.el | 2 +-
lisp/progmodes/c-ts-common.el | 7 +++----
lisp/progmodes/cc-engine.el | 2 +-
lisp/progmodes/cc-fonts.el | 2 +-
lisp/progmodes/cc-langs.el | 2 +-
lisp/progmodes/flymake.el | 2 +-
lisp/term/android-win.el | 2 +-
lisp/touch-screen.el | 2 +-
16 files changed, 18 insertions(+), 19 deletions(-)
diff --git a/admin/cus-test.el b/admin/cus-test.el
index b86643a769a..68907f4f5e5 100644
--- a/admin/cus-test.el
+++ b/admin/cus-test.el
@@ -146,7 +146,7 @@ Names should be as they appear in loaddefs.el.")
(defvar cus-test-errors nil
"List of problematic variables found by `cus-test-apropos'.
-Each element is (VARIABLE . PROBLEM); see `cus-test--format-errors'.")
+Each element is (VARIABLE . PROBLEM); see `cus-test--format-error'.")
(defvar cus-test-tested-variables nil
"List of options tested by last call of `cus-test-apropos'.")
diff --git a/lisp/emacs-lisp/comp-cstr.el b/lisp/emacs-lisp/comp-cstr.el
index c65af16b725..2984bedb1dd 100644
--- a/lisp/emacs-lisp/comp-cstr.el
+++ b/lisp/emacs-lisp/comp-cstr.el
@@ -130,7 +130,7 @@ Integer values are handled in the `range' slot.")
;; TODO we should be able to just cons hash this.
(common-supertype-mem (make-hash-table :test #'equal) :type hash-table
:documentation "Serve memoization for
-`comp-common-supertype'.")
+`comp-ctxt-common-supertype-mem'.")
(subtype-p-mem (make-hash-table :test #'equal) :type hash-table
:documentation "Serve memoization for
`comp-cstr-ctxt-subtype-p-mem'.")
diff --git a/lisp/erc/erc-button.el b/lisp/erc/erc-button.el
index 27406a76f59..6b78e451b54 100644
--- a/lisp/erc/erc-button.el
+++ b/lisp/erc/erc-button.el
@@ -443,7 +443,7 @@ of the channel. However, don't bother creating an actual
Instead, just spoof an `erc-server-user' and stash it during
\"PRIVMSG\" handling via `erc--cmem-from-nick-function' and
retrieve it during buttonizing via
-`erc-button--fallback-user-function'."
+`erc-button--fallback-cmem-function'."
:interactive nil
(if erc-button--phantom-users-mode
(progn
diff --git a/lisp/erc/erc-track.el b/lisp/erc/erc-track.el
index 7e5ed165fb9..04ee76a9349 100644
--- a/lisp/erc/erc-track.el
+++ b/lisp/erc/erc-track.el
@@ -924,7 +924,7 @@ and expected types. This function should return a face or
nil.")
Expect RANKS to be a list of faces and both NORMALS and the car
of NEW-FACES to be hash tables mapping faces to non-nil values.
Assume the latter's makeup and that of RANKS to resemble
-`erc-track-face-normal-list' and `erc-track-faces-priority-list'.
+`erc-track-faces-normal-list' and `erc-track-faces-priority-list'.
If NEW-FACES has a cdr, expect it to be its car's contents
ordered from most recently seen (later in the buffer) to
earliest. In general, act like `erc-track-select-mode-line-face'
diff --git a/lisp/filesets.el b/lisp/filesets.el
index 11576a46936..4e2de8fed1b 100644
--- a/lisp/filesets.el
+++ b/lisp/filesets.el
@@ -286,7 +286,7 @@ See `easy-menu-add-item' for documentation."
)
(defcustom filesets-menu-in-menu nil
- "Use that instead of `current-menubar' as the menu to change.
+ "Use that instead of `current-global-map' as the menu to change.
See `easy-menu-add-item' for documentation."
:set #'filesets-set-default
:type 'sexp)
diff --git a/lisp/forms.el b/lisp/forms.el
index e38fa7ae873..009667af273 100644
--- a/lisp/forms.el
+++ b/lisp/forms.el
@@ -343,7 +343,7 @@ suitable for forms processing.")
(defvar forms-write-file-filter nil
"The name of a function that is called before writing the data file.
-This can be used to undo the effects of `form-read-file-hook'.")
+This can be used to undo the effects of `form-read-file-filter'.")
(defvar forms-new-record-filter nil
"The name of a function that is called when a new record is created.")
diff --git a/lisp/jsonrpc.el b/lisp/jsonrpc.el
index 1f8e1b1a876..14fe0447008 100644
--- a/lisp/jsonrpc.el
+++ b/lisp/jsonrpc.el
@@ -438,7 +438,7 @@ ignored."
`(canceled ,cancel-on-input-retval))
(t (while t (accept-process-output nil 30)))))
;; In normal operation, continuations for error/success is
- ;; handled by `jsonrpc-continue'. Timeouts also remove
+ ;; handled by `jsonrpc--continue'. Timeouts also remove
;; the continuation...
(pcase-let* ((`(,id ,_) id-and-timer))
;; ...but we still have to guard against exist explicit
diff --git a/lisp/net/tramp-sh.el b/lisp/net/tramp-sh.el
index 8ec9467ab45..de515e40345 100644
--- a/lisp/net/tramp-sh.el
+++ b/lisp/net/tramp-sh.el
@@ -4112,7 +4112,7 @@ Only send the definition if it has not already been done."
(unless (member name scripts)
(with-tramp-progress-reporter
vec 5 (format-message "Sending script `%s'" name)
- ;; In bash, leading TABs like in `tramp-vc-registered-read-file-names'
+ ;; In bash, leading TABs like in `tramp-bundle-read-file-names'
;; could result in unwanted command expansion. Avoid this.
(setq script (tramp-compat-string-replace
(make-string 1 ?\t) (make-string 8 ? ) script))
diff --git a/lisp/org/ox-latex.el b/lisp/org/ox-latex.el
index 834fb957329..b409f552a2b 100644
--- a/lisp/org/ox-latex.el
+++ b/lisp/org/ox-latex.el
@@ -3667,7 +3667,7 @@ CONTENTS is the contents of the object."
;; takes care of tables with a "verbatim" mode. Otherwise, it
;; delegates the job to either `org-latex--table.el-table',
;; `org-latex--org-table', `org-latex--math-table' or
-;; `org-latex--org-align-string-tabbing' functions,
+;; `org-table--org-tabbing' functions,
;; depending of the type of the table and the mode requested.
;;
;; `org-latex--align-string' is a subroutine used to build alignment
diff --git a/lisp/progmodes/cc-engine.el b/lisp/progmodes/cc-engine.el
index 4c591fbba36..ea4ee3d7b7c 100644
--- a/lisp/progmodes/cc-engine.el
+++ b/lisp/progmodes/cc-engine.el
@@ -11476,7 +11476,7 @@ This function might do hidden buffer changes."
;; an arglist it would be a meaningless expression because
;; the result isn't used. We therefore choose to recognize
;; it as a declaration when there's "symmetrical WS" around
- ;; the "*" or the flag `c-assymetry-fontification-flag' is
+ ;; the "*" or the flag `c-asymmetry-fontification-flag' is
;; not set. We only allow a suffix (which makes the
;; construct look like a function call) when `at-decl-start'
;; provides additional evidence that we do have a
diff --git a/lisp/progmodes/cc-fonts.el b/lisp/progmodes/cc-fonts.el
index 89f197b98e6..6419d6cf05a 100644
--- a/lisp/progmodes/cc-fonts.el
+++ b/lisp/progmodes/cc-fonts.el
@@ -1112,7 +1112,7 @@ casts and declarations are fontified. Used on level 2
and higher."
;; 'c-decl-type-start (according to TYPES). Stop at LIMIT.
;;
;; If TYPES is t, fontify all identifiers as types; if it is a number, a
- ;; buffer position, additionally set the `c-deftype' text property on the
+ ;; buffer position, additionally set the `c-typedef' text property on the
;; keyword at that position; if it is nil fontify as either variables or
;; functions, otherwise TYPES is a face to use. If NOT-TOP is non-nil, we
;; are not at the top-level ("top-level" includes being directly inside a
diff --git a/lisp/progmodes/cc-langs.el b/lisp/progmodes/cc-langs.el
index ad21bd1d5ef..ba0d1d0fc49 100644
--- a/lisp/progmodes/cc-langs.el
+++ b/lisp/progmodes/cc-langs.el
@@ -817,7 +817,7 @@ there be copies of the opener contained in the multi-line
string."
(c-lang-defconst c-cpp-or-ml-match-offset
;; The offset to be added onto match numbers for a multi-line string in
- ;; matches for `c-cpp-or-ml-string-opener-re'.
+ ;; matches for `c-ml-string-cpp-or-opener-re'.
t (if (c-lang-const c-anchored-cpp-prefix)
(+ 2 (regexp-opt-depth (c-lang-const c-anchored-cpp-prefix)))
2))
diff --git a/lisp/progmodes/flymake.el b/lisp/progmodes/flymake.el
index 3f8aec27833..225f8ecf874 100644
--- a/lisp/progmodes/flymake.el
+++ b/lisp/progmodes/flymake.el
@@ -715,7 +715,7 @@ associated `flymake-category' return DEFAULT."
(delete-overlay ov)))
(defun flymake--eol-overlay-summary (src-ovs)
- "Helper function for `flymake--eol-overlay-update'."
+ "Helper function for `flymake--update-eol-overlays'."
(cl-flet ((summarize (d)
(propertize (flymake-diagnostic-oneliner d t) 'face
(flymake--lookup-type-property (flymake--diag-type d)
diff --git a/lisp/term/android-win.el b/lisp/term/android-win.el
index 876b24683bc..e0d252f17e0 100644
--- a/lisp/term/android-win.el
+++ b/lisp/term/android-win.el
@@ -406,7 +406,7 @@ to grant such permissions.
FANCY-P non-nil means the notice will be displayed with faces, in
the style appropriate for its incorporation within the fancy splash
-screen display; see `francy-splash-insert'."
+screen display; see `fancy-splash-insert'."
(unless (android-external-storage-available-p)
(if fancy-p
(fancy-splash-insert
diff --git a/lisp/touch-screen.el b/lisp/touch-screen.el
index c2f8f8068d7..a1ec4bca89f 100644
--- a/lisp/touch-screen.el
+++ b/lisp/touch-screen.el
@@ -1027,7 +1027,7 @@ POINT was initially placed upon, and pixel deltas
describing how
much point has moved relative to its previous position in the X
and Y axes.
-If the fourth element of `touchscreen-current-tool' is `scroll',
+If the fourth element of `touch-screen-current-tool' is `scroll',
then generate a `touchscreen-scroll' event with the window that
POINT was initially placed upon, and pixel deltas describing how
much point has moved relative to its previous position in the X
[Prev in Thread] |
Current Thread |
[Next in Thread] |
- master 9364c28959a: ; Fix typos in symbol names,
Stefan Kangas <=
diff --git a/lisp/progmodes/c-ts-common.el b/lisp/progmodes/c-ts-common.el
index 07161025d5d..0095d83e302 100644
--- a/lisp/progmodes/c-ts-common.el
+++ b/lisp/progmodes/c-ts-common.el
@@ -37,9 +37,8 @@
;;
;; For indenting statements:
;;
;; - Set `c-ts-common-indent-offset',
;; `c-ts-common-indent-block-type-regexp', and
;; `c-ts-common-indent-bracketless-type-regexp', then use simple-indent
;; offset `c-ts-common-statement-offset' in
;; `treesit-simple-indent-rules'.
@@ -331,7 +330,7 @@ If NODE is nil, return nil."
Assumes the anchor is (point-min), i.e., the 0th column.
This function basically counts the number of block nodes (i.e.,
-brackets) (defined by `c-ts-common-indent-block-type-regexp')
+brackets) (see `c-ts-common-indent-type-regexp-alist')
between NODE and the root node (not counting NODE itself), and
multiply that by `c-ts-common-indent-offset'.
@@ -37,9 +37,8 @@
;; For indenting statements:
;;
-;; - Set `c-ts-common-indent-offset',
-;; `c-ts-common-indent-block-type-regexp', and
-;; `c-ts-common-indent-bracketless-type-regexp', then use simple-indent
+;; - Set `c-ts-common-indent-offset', and
+;; `c-ts-common-indent-type-regexp-alist', then use simple-indent
;; offset `c-ts-common-statement-offset' in
;; `treesit-simple-indent-rules'.